@@ -1,6 +1,8 @@
 #!/usr/bin/env python
 
 
+from __future__ import annotations
+
 import pkg_resources
 
 __version__: str = pkg_resources.get_distribution(__name__).version
@@ -32,6 +34,7 @@ for i, arg in enumerate(sys.argv):
 from .utils.commands import *  # isort:skip
 
 from .animation.animation import *
+from .animation.changing import *
 from .animation.composition import *
 from .animation.creation import *
 from .animation.fading import *
@@ -43,42 +46,43 @@ from .animation.rotation import *
 from .animation.specialized import *
 from .animation.transform import *
 from .animation.transform_matching_parts import *
-from .animation.update import *
+from .animation.updaters.mobject_update_utils import *
+from .animation.updaters.update import *
 from .camera.camera import *
 from .camera.mapping_camera import *
 from .camera.moving_camera import *
 from .camera.multi_camera import *
 from .camera.three_d_camera import *
 from .constants import *
-from .mobject.boolean_ops import *
-from .mobject.changing import *
-from .mobject.coordinate_systems import *
 from .mobject.frame import *
-from .mobject.functions import *
-from .mobject.geometry import *
+from .mobject.geometry.arc import *
+from .mobject.geometry.boolean_ops import *
+from .mobject.geometry.line import *
+from .mobject.geometry.polygram import *
+from .mobject.geometry.shape_matchers import *
+from .mobject.geometry.tips import *
 from .mobject.graph import *
+from .mobject.graphing.coordinate_systems import *
+from .mobject.graphing.functions import *
+from .mobject.graphing.number_line import *
+from .mobject.graphing.probability import *
+from .mobject.graphing.scale import *
 from .mobject.logo import *
 from .mobject.matrix import *
 from .mobject.mobject import *
-from .mobject.mobject_update_utils import *
-from .mobject.number_line import *
-from .mobject.numbers import *
-from .mobject.polyhedra import *
-from .mobject.probability import *
-from .mobject.shape_matchers import *
+from .mobject.opengl.dot_cloud import *
+from .mobject.opengl.opengl_point_cloud_mobject import *
 from .mobject.svg.brace import *
-from .mobject.svg.code_mobject import *
-from .mobject.svg.style_utils import *
 from .mobject.svg.svg_mobject import *
-from .mobject.svg.svg_path import *
-from .mobject.svg.tex_mobject import *
-from .mobject.svg.text_mobject import *
 from .mobject.table import *
-from .mobject.three_d_utils import *
-from .mobject.three_dimensions import *
-from .mobject.types.dot_cloud import *
+from .mobject.text.code_mobject import *
+from .mobject.text.numbers import *
+from .mobject.text.tex_mobject import *
+from .mobject.text.text_mobject import *
+from .mobject.three_d.polyhedra import *
+from .mobject.three_d.three_d_utils import *
+from .mobject.three_d.three_dimensions import *
 from .mobject.types.image_mobject import *
-from .mobject.types.opengl_point_cloud_mobject import *
 from .mobject.types.point_cloud_mobject import *
 from .mobject.types.vectorized_mobject import *
 from .mobject.value_tracker import *
@@ -101,7 +105,6 @@ from .utils.images import *
 from .utils.iterables import *
 from .utils.paths import *
 from .utils.rate_functions import *
-from .utils.scale import *
 from .utils.simple_functions import *
 from .utils.sounds import *
 from .utils.space_ops import *
