@@ -9,6 +9,8 @@ movie vs writing a single frame).
 See :doc:`/tutorials/configuration` for an introduction to Manim's configuration system.
 
 """
+from __future__ import annotations
+
 import argparse
 import configparser
 import copy
@@ -30,7 +32,7 @@ from ..utils.tex_templates import TexTemplateLibrary
 from .logger_utils import set_file_logger
 
 
-def config_file_paths() -> typing.List[Path]:
+def config_file_paths() -> list[Path]:
     """The paths where ``.cfg`` files will be searched for.
 
     When manim is first imported, it processes any ``.cfg`` files it finds.  This
@@ -251,6 +253,7 @@ class ManimConfig(MutableMapping):
         "from_animation_number",
         "images_dir",
         "input_file",
+        "media_embed",
         "media_width",
         "webgl_renderer_path",
         "log_dir",
@@ -320,7 +323,7 @@ class ManimConfig(MutableMapping):
     def __setitem__(self, key: str, val: typing.Any) -> None:
         getattr(ManimConfig, key).fset(self, val)  # fset is the property's setter
 
-    def update(self, obj: typing.Union["ManimConfig", dict]) -> None:
+    def update(self, obj: ManimConfig | dict) -> None:
         """Digest the options found in another :class:`ManimConfig` or in a dict.
 
         Similar to :meth:`dict.update`, replaces the values of this object with
@@ -369,7 +372,7 @@ class ManimConfig(MutableMapping):
         raise AttributeError("'ManimConfig' object does not support item deletion")
 
     # copy functions
-    def copy(self) -> "ManimConfig":
+    def copy(self) -> ManimConfig:
         """Deepcopy the contents of this ManimConfig.
 
         Returns
@@ -388,11 +391,11 @@ class ManimConfig(MutableMapping):
         """
         return copy.deepcopy(self)
 
-    def __copy__(self) -> "ManimConfig":
+    def __copy__(self) -> ManimConfig:
         """See ManimConfig.copy()."""
         return copy.deepcopy(self)
 
-    def __deepcopy__(self, memo: typing.Dict[str, typing.Any]) -> "ManimConfig":
+    def __deepcopy__(self, memo: dict[str, typing.Any]) -> ManimConfig:
         """See ManimConfig.copy()."""
         c = ManimConfig()
         # Deepcopying the underlying dict is enough because all properties
@@ -409,7 +412,7 @@ class ManimConfig(MutableMapping):
         else:
             raise ValueError(f"attempted to set {key} to {val}; must be in {values}")
 
-    def _set_boolean(self, key: typing.Union[str, int], val: typing.Any) -> None:
+    def _set_boolean(self, key: str | int, val: typing.Any) -> None:
         """Set ``key`` to ``val`` if ``val`` is Boolean."""
         if val in [True, False]:
             self._d[key] = val
@@ -465,7 +468,7 @@ class ManimConfig(MutableMapping):
         return rep
 
     # builders
-    def digest_parser(self, parser: configparser.ConfigParser) -> "ManimConfig":
+    def digest_parser(self, parser: configparser.ConfigParser) -> ManimConfig:
         """Process the config options present in a :class:`ConfigParser` object.
 
         This method processes arbitrary parsers, not only those read from a
@@ -625,6 +628,12 @@ class ManimConfig(MutableMapping):
         if val:
             self.ffmpeg_loglevel = val
 
+        try:
+            val = parser["jupyter"].getboolean("media_embed")
+        except ValueError:
+            val = None
+        setattr(self, "media_embed", val)
+
         val = parser["jupyter"].get("media_width")
         if val:
             setattr(self, "media_width", val)
@@ -635,7 +644,7 @@ class ManimConfig(MutableMapping):
 
         return self
 
-    def digest_args(self, args: argparse.Namespace) -> "ManimConfig":
+    def digest_args(self, args: argparse.Namespace) -> ManimConfig:
         """Process the config options present in CLI arguments.
 
         Parameters
@@ -788,7 +797,7 @@ class ManimConfig(MutableMapping):
 
         return self
 
-    def digest_file(self, filename: str) -> "ManimConfig":
+    def digest_file(self, filename: str) -> ManimConfig:
         """Process the config options present in a ``.cfg`` file.
 
         This method processes a single ``.cfg`` file, whereas
@@ -969,6 +978,12 @@ class ManimConfig(MutableMapping):
         doc="Verbosity level of ffmpeg (no flag).",
     )
 
+    media_embed = property(
+        lambda self: self._d["media_embed"],
+        lambda self, val: self._d.__setitem__("media_embed", val),
+        doc="Embed videos in Jupyter notebook",
+    )
+
     media_width = property(
         lambda self: self._d["media_width"],
         lambda self, val: self._d.__setitem__("media_width", val),
@@ -1173,10 +1188,11 @@ class ManimConfig(MutableMapping):
     def renderer(self, val: str) -> None:
         """Renderer for animations."""
         try:
+            from manim.mobject.opengl.opengl_compatibility import ConvertToOpenGL
+            from manim.mobject.opengl.opengl_mobject import OpenGLMobject
+            from manim.mobject.opengl.opengl_vectorized_mobject import OpenGLVMobject
+
             from ..mobject.mobject import Mobject
-            from ..mobject.opengl_compatibility import ConvertToOpenGL
-            from ..mobject.opengl_mobject import OpenGLMobject
-            from ..mobject.types.opengl_vectorized_mobject import OpenGLVMobject
             from ..mobject.types.vectorized_mobject import VMobject
 
             for cls in ConvertToOpenGL._converted_classes:
@@ -1459,7 +1475,7 @@ class ManimConfig(MutableMapping):
                 ) from exc
         return Path(path) if path else None
 
-    def _set_dir(self, key: str, val: typing.Union[str, Path]):
+    def _set_dir(self, key: str, val: str | Path):
         if isinstance(val, Path):
             self._d.__setitem__(key, str(val))
         else:
@@ -1549,7 +1565,7 @@ class ManimConfig(MutableMapping):
         return self._tex_template
 
     @tex_template.setter
-    def tex_template(self, val: typing.Union[TexTemplateFromFile, TexTemplate]) -> None:
+    def tex_template(self, val: TexTemplateFromFile | TexTemplate) -> None:
         if isinstance(val, (TexTemplateFromFile, TexTemplate)):
             self._tex_template = val
 
@@ -1583,7 +1599,7 @@ class ManimConfig(MutableMapping):
 
 
 class ManimFrame(Mapping):
-    _OPTS: typing.Set[str] = {
+    _OPTS: set[str] = {
         "pixel_width",
         "pixel_height",
         "aspect_ratio",
@@ -1596,7 +1612,7 @@ class ManimFrame(Mapping):
         "left_side",
         "right_side",
     }
-    _CONSTANTS: typing.Dict[str, np.ndarray] = {
+    _CONSTANTS: dict[str, np.ndarray] = {
         "UP": np.array((0.0, 1.0, 0.0)),
         "DOWN": np.array((0.0, -1.0, 0.0)),
         "RIGHT": np.array((1.0, 0.0, 0.0)),
@@ -1621,7 +1637,7 @@ class ManimFrame(Mapping):
         self.__dict__["_c"] = c
 
     # there are required by parent class Mapping to behave like a dict
-    def __getitem__(self, key: typing.Union[str, int]) -> typing.Any:
+    def __getitem__(self, key: str | int) -> typing.Any:
         if key in self._OPTS:
             return self._c[key]
         elif key in self._CONSTANTS:
