@@ -1,27 +1,21 @@
 """Animate mobjects."""
 
 
+from __future__ import annotations
+
+from manim.mobject.opengl.opengl_mobject import OpenGLMobject
+
 from .. import config, logger
-from ..mobject import mobject, opengl_mobject
+from ..mobject import mobject
 from ..mobject.mobject import Mobject
-from ..mobject.opengl_mobject import OpenGLMobject
+from ..mobject.opengl import opengl_mobject
 from ..utils.rate_functions import smooth
 
 __all__ = ["Animation", "Wait", "override_animation"]
 
 
 from copy import deepcopy
-from typing import (
-    TYPE_CHECKING,
-    Callable,
-    Iterable,
-    List,
-    Optional,
-    Sequence,
-    Tuple,
-    Type,
-    Union,
-)
+from typing import TYPE_CHECKING, Callable, Iterable, Sequence
 
 if TYPE_CHECKING:
     from manim.scene.scene import Scene
@@ -125,22 +119,27 @@ class Animation:
 
     def __init__(
         self,
-        mobject: Optional[Mobject],
+        mobject: Mobject | None,
         lag_ratio: float = DEFAULT_ANIMATION_LAG_RATIO,
         run_time: float = DEFAULT_ANIMATION_RUN_TIME,
         rate_func: Callable[[float], float] = smooth,
         name: str = None,
         remover: bool = False,  # remove a mobject from the screen?
         suspend_mobject_updating: bool = True,
+        introducer: bool = False,
+        *,
+        _on_finish: Callable[[], None] = lambda _: None,
         **kwargs,
     ) -> None:
         self._typecheck_input(mobject)
         self.run_time: float = run_time
         self.rate_func: Callable[[float], float] = rate_func
-        self.name: Optional[str] = name
+        self.name: str | None = name
         self.remover: bool = remover
+        self.introducer: bool = introducer
         self.suspend_mobject_updating: bool = suspend_mobject_updating
         self.lag_ratio: float = lag_ratio
+        self._on_finish: Callable[[Scene], None] = _on_finish
         if config["renderer"] == "opengl":
             self.starting_mobject: OpenGLMobject = OpenGLMobject()
             self.mobject: OpenGLMobject = (
@@ -160,7 +159,7 @@ class Animation:
                 ),
             )
 
-    def _typecheck_input(self, mobject: Union[Mobject, None]) -> None:
+    def _typecheck_input(self, mobject: Mobject | None) -> None:
         if mobject is None:
             logger.debug("Animation with empty mobject")
         elif not isinstance(mobject, (Mobject, OpenGLMobject)):
@@ -206,7 +205,7 @@ class Animation:
         if self.suspend_mobject_updating and self.mobject is not None:
             self.mobject.resume_updating()
 
-    def clean_up_from_scene(self, scene: "Scene") -> None:
+    def clean_up_from_scene(self, scene: Scene) -> None:
         """Clean up the :class:`~.Scene` after finishing the animation.
 
         This includes to :meth:`~.Scene.remove` the Animation's
@@ -217,9 +216,26 @@ class Animation:
         scene
             The scene the animation should be cleaned up from.
         """
+        self._on_finish(scene)
         if self.is_remover():
             scene.remove(self.mobject)
 
+    def _setup_scene(self, scene: Scene) -> None:
+        """Setup up the :class:`~.Scene` before starting the animation.
+
+        This includes to :meth:`~.Scene.add` the Animation's
+        :class:`~.Mobject` if the animation is an introducer.
+
+        Parameters
+        ----------
+        scene
+            The scene the animation should be cleaned up from.
+        """
+        if scene is None:
+            return
+        if self.is_introducer():
+            scene.add(self.mobject)
+
     def create_starting_mobject(self) -> Mobject:
         # Keep track of where the mobject starts
         return self.mobject.copy()
@@ -236,7 +252,7 @@ class Animation:
         """
         return self.mobject, self.starting_mobject
 
-    def get_all_families_zipped(self) -> Iterable[Tuple]:
+    def get_all_families_zipped(self) -> Iterable[tuple]:
         if config["renderer"] == "opengl":
             return zip(*(mob.get_family() for mob in self.get_all_mobjects()))
         return zip(
@@ -254,7 +270,7 @@ class Animation:
         for mob in self.get_all_mobjects_to_update():
             mob.update(dt)
 
-    def get_all_mobjects_to_update(self) -> List[Mobject]:
+    def get_all_mobjects_to_update(self) -> list[Mobject]:
         """Get all mobjects to be updated during the animation.
 
         Returns
@@ -267,7 +283,7 @@ class Animation:
         # most cases its updating is suspended anyway
         return list(filter(lambda m: m is not self.mobject, self.get_all_mobjects()))
 
-    def copy(self) -> "Animation":
+    def copy(self) -> Animation:
         """Create a copy of the animation.
 
         Returns
@@ -314,7 +330,7 @@ class Animation:
         starting_submobject: Mobject,
         # target_copy: Mobject, #Todo: fix - signature of interpolate_submobject differs in Transform().
         alpha: float,
-    ) -> "Animation":
+    ) -> Animation:
         # Typically implemented by subclass
         pass
 
@@ -345,7 +361,7 @@ class Animation:
         return self.rate_func(value - lower)
 
     # Getters and setters
-    def set_run_time(self, run_time: float) -> "Animation":
+    def set_run_time(self, run_time: float) -> Animation:
         """Set the run time of the animation.
 
         Parameters
@@ -379,7 +395,7 @@ class Animation:
     def set_rate_func(
         self,
         rate_func: Callable[[float], float],
-    ) -> "Animation":
+    ) -> Animation:
         """Set the rate function of the animation.
 
         Parameters
@@ -408,7 +424,7 @@ class Animation:
         """
         return self.rate_func
 
-    def set_name(self, name: str) -> "Animation":
+    def set_name(self, name: str) -> Animation:
         """Set the name of the animation.
 
         Parameters
@@ -434,10 +450,20 @@ class Animation:
         """
         return self.remover
 
+    def is_introducer(self) -> bool:
+        """Test if a the animation is a remover.
+
+        Returns
+        -------
+        bool
+            ``True`` if the animation is a remover, ``False`` otherwise.
+        """
+        return self.introducer
+
 
 def prepare_animation(
-    anim: Union["Animation", "mobject._AnimationBuilder"],
-) -> "Animation":
+    anim: Animation | mobject._AnimationBuilder,
+) -> Animation:
     r"""Returns either an unchanged animation, or the animation built
     from a passed animation factory.
 
@@ -477,12 +503,41 @@ def prepare_animation(
 
 
 class Wait(Animation):
+    """A "no operation" animation.
+
+    Parameters
+    ----------
+    run_time
+        The amount of time that should pass.
+    stop_condition
+        A function without positional arguments that evaluates to a boolean.
+        The function is evaluated after every new frame has been rendered.
+        Playing the animation only stops after the return value is truthy.
+        Overrides the specified ``run_time``.
+    frozen_frame
+        Controls whether or not the wait animation is static, i.e., corresponds
+        to a frozen frame. If ``False`` is passed, the render loop still
+        progresses through the animation as usual and (among other things)
+        continues to call updater functions. If ``None`` (the default value),
+        the :meth:`.Scene.play` call tries to determine whether the Wait call
+        can be static or not itself via :meth:`.Scene.should_mobjects_update`.
+    kwargs
+        Keyword arguments to be passed to the parent class, :class:`.Animation`.
+    """
+
     def __init__(
-        self, run_time: float = 1, stop_condition=None, **kwargs
-    ):  # what is stop_condition?
+        self,
+        run_time: float = 1,
+        stop_condition: Callable[[], bool] | None = None,
+        frozen_frame: bool | None = None,
+        **kwargs,
+    ):
+        if stop_condition and frozen_frame:
+            raise ValueError("A static Wait animation cannot have a stop condition.")
+
         self.duration: float = run_time
         self.stop_condition = stop_condition
-        self.is_static_wait: bool = False
+        self.is_static_wait: bool = frozen_frame
         super().__init__(None, run_time=run_time, **kwargs)
         # quick fix to work in opengl setting:
         self.mobject.shader_wrapper_list = []
@@ -493,7 +548,7 @@ class Wait(Animation):
     def finish(self) -> None:
         pass
 
-    def clean_up_from_scene(self, scene: "Scene") -> None:
+    def clean_up_from_scene(self, scene: Scene) -> None:
         pass
 
     def update_mobjects(self, dt: float) -> None:
@@ -504,7 +559,7 @@ class Wait(Animation):
 
 
 def override_animation(
-    animation_class: Type["Animation"],
+    animation_class: type[Animation],
 ) -> Callable[[Callable], Callable]:
     """Decorator used to mark methods as overrides for specific :class:`~.Animation` types.
 
