@@ -1,21 +1,24 @@
 """A camera that can be positioned and oriented in three-dimensional space."""
 
+from __future__ import annotations
+
 __all__ = ["ThreeDCamera"]
 
 
 import numpy as np
 
-from .. import config
-from ..camera.camera import Camera
-from ..constants import *
-from ..mobject.three_d_utils import (
+from manim.mobject.three_d.three_d_utils import (
     get_3d_vmob_end_corner,
     get_3d_vmob_end_corner_unit_normal,
     get_3d_vmob_start_corner,
     get_3d_vmob_start_corner_unit_normal,
 )
+from manim.mobject.value_tracker import ValueTracker
+
+from .. import config
+from ..camera.camera import Camera
+from ..constants import *
 from ..mobject.types.point_cloud_mobject import Point
-from ..mobject.value_tracker import ValueTracker
 from ..utils.color import get_shaded_rgb
 from ..utils.family import extract_mobject_family_members
 from ..utils.space_ops import rotation_about_z, rotation_matrix
@@ -34,7 +37,7 @@ class ThreeDCamera(Camera):
         theta=-90 * DEGREES,
         gamma=0,
         zoom=1,
-        **kwargs
+        **kwargs,
     ):
         """Initializes the ThreeDCamera
 
@@ -314,7 +317,7 @@ class ThreeDCamera(Camera):
                 factor[lt0] = focal_distance / (focal_distance - zs[lt0])
             else:
                 factor = focal_distance / (focal_distance - zs)
-                factor[(focal_distance - zs) < 0] = 10 ** 6
+                factor[(focal_distance - zs) < 0] = 10**6
             points[:, i] *= factor * zoom
         return points
 
@@ -417,7 +420,7 @@ class ThreeDCamera(Camera):
         """
         for mobject in extract_mobject_family_members(mobjects):
             if mobject in self.fixed_orientation_mobjects:
-                self.fixed_orientation_mobjects.remove(mobject)
+                del self.fixed_orientation_mobjects[mobject]
 
     def remove_fixed_in_frame_mobjects(self, *mobjects):
         """If a mobject was fixed in frame by passing it through
