@@ -5,15 +5,16 @@ cfg``. Here you can specify options, subcommands, and subgroups for the cfg
 group.
 
 """
+from __future__ import annotations
+
 import os
 from ast import literal_eval
-from typing import Union
 
 import click
 from rich.errors import StyleSyntaxError
 from rich.style import Style
 
-from ... import config, console
+from ... import console
 from ..._config.utils import config_file_paths, make_config_parser
 from ...constants import CONTEXT_SETTINGS, EPILOG
 from ...utils.file_ops import guarantee_existence, open_file
@@ -26,7 +27,7 @@ If left empty, the default colour will be used.[/red]
 RICH_NON_STYLE_ENTRIES: str = ["log.width", "log.height", "log.timestamps"]
 
 
-def value_from_string(value: str) -> Union[str, int, bool]:
+def value_from_string(value: str) -> str | int | bool:
     """Extracts the literal of proper datatype from a string.
     Parameters
     ----------
