@@ -26,6 +26,8 @@ Examples
             self.add(g)
 """
 
+from __future__ import annotations
+
 __all__ = [
     "Matrix",
     "DecimalMatrix",
@@ -38,16 +40,16 @@ __all__ = [
 
 
 import itertools as it
-from typing import Iterable, Sequence, Type
+from typing import Iterable, Sequence
 
 import numpy as np
 
+from manim.mobject.opengl.opengl_compatibility import ConvertToOpenGL
+from manim.mobject.text.numbers import DecimalNumber, Integer
+from manim.mobject.text.tex_mobject import MathTex, Tex
+
 from ..constants import *
-from ..mobject.numbers import DecimalNumber, Integer
-from ..mobject.svg.tex_mobject import MathTex, Tex
 from ..mobject.types.vectorized_mobject import VGroup, VMobject
-from ..utils.color import WHITE
-from .opengl_compatibility import ConvertToOpenGL
 
 # TO DO : The following two functions are not used in this file.
 #         Not sure if we should keep it or not.
@@ -134,7 +136,7 @@ class Matrix(VMobject, metaclass=ConvertToOpenGL):
         bracket_v_buff: float = MED_SMALL_BUFF,
         add_background_rectangles_to_entries: bool = False,
         include_background_rectangle: bool = False,
-        element_to_mobject: Type[MathTex] = MathTex,
+        element_to_mobject: type[MathTex] = MathTex,
         element_to_mobject_config: dict = {},
         element_alignment_corner: Sequence[float] = DR,
         left_bracket: str = "[",
@@ -189,11 +191,11 @@ class Matrix(VMobject, metaclass=ConvertToOpenGL):
         self.left_bracket = left_bracket
         self.right_bracket = right_bracket
         super().__init__(**kwargs)
-        mob_matrix = self.matrix_to_mob_matrix(matrix)
-        self.organize_mob_matrix(mob_matrix)
+        mob_matrix = self._matrix_to_mob_matrix(matrix)
+        self._organize_mob_matrix(mob_matrix)
         self.elements = VGroup(*it.chain(*mob_matrix))
         self.add(self.elements)
-        self.add_brackets(self.left_bracket, self.right_bracket, **bracket_config)
+        self._add_brackets(self.left_bracket, self.right_bracket, **bracket_config)
         self.center()
         self.mob_matrix = mob_matrix
         if self.add_background_rectangles_to_entries:
@@ -202,8 +204,7 @@ class Matrix(VMobject, metaclass=ConvertToOpenGL):
         if self.include_background_rectangle:
             self.add_background_rectangle()
 
-    def matrix_to_mob_matrix(self, matrix):
-        """Used internally."""
+    def _matrix_to_mob_matrix(self, matrix):
         return [
             [
                 self.element_to_mobject(item, **self.element_to_mobject_config)
@@ -212,8 +213,7 @@ class Matrix(VMobject, metaclass=ConvertToOpenGL):
             for row in matrix
         ]
 
-    def organize_mob_matrix(self, matrix):
-        """Used internally."""
+    def _organize_mob_matrix(self, matrix):
         for i, row in enumerate(matrix):
             for j, _ in enumerate(row):
                 mob = matrix[i][j]
@@ -223,8 +223,8 @@ class Matrix(VMobject, metaclass=ConvertToOpenGL):
                 )
         return self
 
-    def add_brackets(self, left="[", right="]", **kwargs):
-        """Used internally. Adds the brackets to the Matrix mobject.
+    def _add_brackets(self, left="[", right="]", **kwargs):
+        """Adds the brackets to the Matrix mobject.
 
         See Latex document for various bracket types.
 
