@@ -1,5 +1,6 @@
+from __future__ import annotations
+
 import copy
-from dataclasses import dataclass
 
 from manim import config
 
