@@ -1,5 +1,7 @@
 """Basic canvas for animations."""
 
+from __future__ import annotations
+
 __all__ = ["Scene"]
 
 import copy
@@ -11,7 +13,7 @@ import threading
 import time
 import types
 from queue import Queue
-from typing import List, Optional
+from typing import Callable
 
 import srt
 
@@ -28,12 +30,13 @@ from tqdm import tqdm
 from watchdog.events import FileSystemEventHandler
 from watchdog.observers import Observer
 
+from manim.mobject.opengl.opengl_mobject import OpenGLPoint
+
 from .. import config, logger
 from ..animation.animation import Animation, Wait, prepare_animation
 from ..camera.camera import Camera
 from ..constants import *
 from ..gui.gui import configure_pygui
-from ..mobject.opengl_mobject import OpenGLPoint
 from ..renderer.cairo_renderer import CairoRenderer
 from ..renderer.opengl_renderer import OpenGLRenderer
 from ..renderer.shader import Object3D
@@ -346,18 +349,33 @@ class Scene:
         for func in self.updaters:
             func(dt)
 
-    def should_update_mobjects(self):
+    def should_update_mobjects(self) -> bool:
         """
-        Returns True if any mobject in Scene is being updated
-        or if the scene has always_update_mobjects set to true.
+        Returns True if the mobjects of this scene should be updated.
 
-        Returns
-        -------
-            bool
+        In particular, this checks whether
+
+        - the :attr:`always_update_mobjects` attribute of :class:`.Scene`
+          is set to ``True``,
+        - the :class:`.Scene` itself has time-based updaters attached,
+        - any mobject in this :class:`.Scene` has time-based updaters attached.
+
+        This is only called when a single Wait animation is played.
         """
-        return self.always_update_mobjects or any(
-            [mob.has_time_based_updater() for mob in self.get_mobject_family_members()],
-        )
+        wait_animation = self.animations[0]
+        if wait_animation.is_static_wait is None:
+            should_update = (
+                self.always_update_mobjects
+                or self.updaters
+                or any(
+                    [
+                        mob.has_time_based_updater()
+                        for mob in self.get_mobject_family_members()
+                    ],
+                )
+            )
+            wait_animation.is_static_wait = not should_update
+        return not wait_animation.is_static_wait
 
     def get_top_level_mobjects(self):
         """
@@ -433,7 +451,7 @@ class Scene:
             mobjects = [*mobjects, *self.foreground_mobjects]
             self.restructure_mobjects(to_remove=mobjects)
             self.mobjects += mobjects
-            if self.moving_mobjects:
+            if self.moving_mobjects is not None:
                 self.restructure_mobjects(
                     to_remove=mobjects,
                     mobject_list_name="moving_mobjects",
@@ -444,6 +462,8 @@ class Scene:
     def add_mobjects_from_animations(self, animations):
         curr_mobjects = self.get_mobject_family_members()
         for animation in animations:
+            if animation.is_introducer():
+                continue
             # Anything animated that's not already in the
             # scene gets added to the scene
             mob = animation.mobject
@@ -949,8 +969,56 @@ class Scene:
                 offset=-run_time + subcaption_offset,
             )
 
-    def wait(self, duration=DEFAULT_WAIT_TIME, stop_condition=None):
-        self.play(Wait(run_time=duration, stop_condition=stop_condition))
+    def wait(
+        self,
+        duration: float = DEFAULT_WAIT_TIME,
+        stop_condition: Callable[[], bool] | None = None,
+        frozen_frame: bool | None = None,
+    ):
+        """Plays a "no operation" animation.
+
+        Parameters
+        ----------
+        duration
+            The run time of the animation.
+        stop_condition
+            A function without positional arguments that is evaluated every time
+            a frame is rendered. The animation only stops when the return value
+            of the function is truthy. Overrides any value passed to ``duration``.
+        frozen_frame
+            If True, updater functions are not evaluated, and the animation outputs
+            a frozen frame. If False, updater functions are called and frames
+            are rendered as usual. If None (the default), the scene tries to
+            determine whether or not the frame is frozen on its own.
+
+        See also
+        --------
+        :class:`.Wait`, :meth:`.should_mobjects_update`
+        """
+        self.play(
+            Wait(
+                run_time=duration,
+                stop_condition=stop_condition,
+                frozen_frame=frozen_frame,
+            )
+        )
+
+    def pause(self, duration: float = DEFAULT_WAIT_TIME):
+        """Pauses the scene (i.e., displays a frozen frame).
+
+        This is an alias for :meth:`.wait` with ``frozen_frame``
+        set to ``True``.
+
+        Parameters
+        ----------
+        duration
+            The duration of the pause.
+
+        See also
+        --------
+        :meth:`.wait`, :class:`.Wait`
+        """
+        self.wait(duration=duration, frozen_frame=True)
 
     def wait_until(self, stop_condition, max_time=60):
         """
@@ -997,29 +1065,29 @@ class Scene:
         self.moving_mobjects = []
         self.static_mobjects = []
 
-        if config.renderer != "opengl":
-            if len(self.animations) == 1 and isinstance(self.animations[0], Wait):
+        if len(self.animations) == 1 and isinstance(self.animations[0], Wait):
+            if self.should_update_mobjects():
                 self.update_mobjects(dt=0)  # Any problems with this?
-                if self.should_update_mobjects():
-                    self.stop_condition = self.animations[0].stop_condition
-                else:
-                    self.duration = self.animations[0].duration
-                    # Static image logic when the wait is static is done by the renderer, not here.
-                    self.animations[0].is_static_wait = True
-                    return None
+                self.stop_condition = self.animations[0].stop_condition
             else:
-                # Paint all non-moving objects onto the screen, so they don't
-                # have to be rendered every frame
-                (
-                    self.moving_mobjects,
-                    self.static_mobjects,
-                ) = self.get_moving_and_static_mobjects(self.animations)
+                self.duration = self.animations[0].duration
+                # Static image logic when the wait is static is done by the renderer, not here.
+                self.animations[0].is_static_wait = True
+                return None
+        elif config.renderer != "opengl":
+            # Paint all non-moving objects onto the screen, so they don't
+            # have to be rendered every frame
+            (
+                self.moving_mobjects,
+                self.static_mobjects,
+            ) = self.get_moving_and_static_mobjects(self.animations)
         self.duration = self.get_run_time(self.animations)
         return self
 
     def begin_animations(self) -> None:
         """Start the animations of the scene."""
         for animation in self.animations:
+            animation._setup_scene(self)
             animation.begin()
 
     def is_current_animation_frozen_frame(self) -> bool:
@@ -1100,7 +1168,6 @@ class Scene:
         self.interactive_mode = True
 
         def ipython(shell, namespace):
-            import manim
             import manim.opengl
 
             def load_module_into_namespace(module, namespace):
